==> deverhood-react-1.16.51.tgz: package/src/actions/actionType.js <==
export const REQUEST = "REQUEST";
export const SENDING = "SENDING";
export const SUCCESS = "SUCCESS";
export const FAILURE = "FAILURE";
export const CALLBACK_SUCCESS = "CALLBACK_SUCCESS";
export const CALLBACK_FAIL = "CALLBACK_FAIL";
export const CALLBACK_LOADING = "CALLBACK_LOADING";
export const CALLBACK_OUT = "CALLBACK_OUT";
export const CALLBACK_NEW = "CALLBACK_NEW";
export const CALLBACK_PRIORITY = "CALLBACK_PRIORITY";
export const CALLBACK_CLEAR = "CALLBACK_CLEAR";
//ACTIONS
//REST APIs
export const GET = "GET";
export const POST = "POST";
export const PUT = "PUT";
export const DEL = "DEL";
export const GETID = "GETID";
export const ALL = "ALL";
export const SEARCH = "SEARCH";
export const SELF = "SELF";
export const CLEAR = "CLEAR";
export const FORM = "FORM";
export const CLONE = "CLONE";
export const CLONE_MANU = "CLONE_MANU";
export const COMPARE = "COMPARE";
export const MAJOR = "MAJOR";
export const FILE = "FILE";
export const EVALUATION = "EVALUATION";
export const COMMENT = "COMMENT";
export const SIGNUP = "SIGNUP";
export const VERIFY = "VERIFY";
export const INSTITUTE = "INSTITUTE";
export const TEXT = "TEXT";
export const CHECKBOX = "CHECKBOX";
export const MULTIPLE_CHOICE = "MULTIPLE_CHOICE";
export const ITEM = "ITEM";
export const FORM_EVALUATION = "FORM_EVALUATION";
export const TYPE = "TYPE";
export const DATE = "DATE";
export const TIME = "TIME";
export const DATETIME = "DATETIME";
export const SCALE = "SCALE";
export const CHECKBOX_GRID = "CHECKBOX_GRID";
export const IMAGE = "IMAGE";
export const VIDEO = "VIDEO";
export const GRID = "GRID";
export const DROPDOWN = "DROPDOWN";
export const RESPONSE = "RESPONSE";
export const SECTION_HEADER = "SECTION_HEADER";
export const SECTION = "SECTION";
export const VERIFY_CODE = "VERIFY_CODE";
export const ME = "ME";
export const EXTERNAL_SIGNUP = "EXTERNAL_SIGNUP";
export const LIST = "LIST";
export const FORGOT = "FORGOT";
export const RESET = "RESET";
export const EQUATION = "EQUATION";
export const STAT = "STAT";
export const MOVE = "MOVE";
export const TAG = "TAG";
export const CONDITION = "CONDITION";
export const HEADER = "HEADER";
//WFME
export const CURRICULUM = "CURRICULUM";
export const KPI = "KPI";
export const COURSE = "COURSE";
export const COURSE_OFFER = "COURSE_OFFER";
export const ANSWER = "ANSWER";
export const OUTCOME = "OUTCOME";
export const DEPARTMENT = "DEPARTMENT";
export const FILE_NAME = "FILE_NAME";
export const BUNDLE = "BUNDLE";
export const ACADYEAR = "ACADYEAR";
export const OUTCOME_FORM = "OUTCOME_FORM";
export const CUCAS = "CUCAS";
export const CUCAS_USER = "CUCAS_USER";
//WFME
export const wfmes = [
  SELF,
  CLEAR,
  KPI,
  COURSE,
  COURSE_OFFER,
  ANSWER,
  FILE,
  OUTCOME,
  DEPARTMENT,
  CURRICULUM,
  FILE_NAME,
  RESPONSE,
  BUNDLE,
  ACADYEAR,
  OUTCOME_FORM,
  CUCAS,
  CUCAS_USER
];
function createWFME(base) {
  return wfmes.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const WFME_REQUEST = "WFME_REQUEST";
export const WFME_API = createWFME("WFME_API");
//
//HIS
export const INVENTORY = "INVENTORY";
export const UNIT = "UNIT";
export const LOTS = "LOTS";
export const MEDICATION = "MEDICATION";
export const INVOICE = "INVOICE";
export const OWN_MEDICATION = "OWN_MEDICATION";
export const his = [
  SELF,
  CLEAR,
  INVENTORY,
  UNIT,
  LOTS,
  MEDICATION,
  INVOICE,
  OWN_MEDICATION
];
function createHis(base) {
  return his.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const HIS_REQUEST = "HIS_REQUEST";
export const HIS_API = createHis("HIS_API");
//MEDIC
export const PATIENT = "PATIENT";
export const FOLLOWUP = "FOLLOWUP";
export const LATEST_FOLLOWUP = "LATEST_FOLLOWUP";
export const ANNOTATE = "ANNOTATE";
export const OWN = "OWN";
export const UPLOAD = "UPLOAD";
export const STAT_GROUP = "STAT_GROUP"; //Form stat group
//MEDIC
export const medics = [
  SELF,
  CLEAR,
  PATIENT,
  FOLLOWUP,
  LATEST_FOLLOWUP,
  FILE,
  FORM,
  ANNOTATE,
  OWN,
  STAT,
  HEADER,
  UPLOAD,
  STAT_GROUP
];
function createMedic(base) {
  return medics.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const MEDIC_REQUEST = "MEDIC_REQUEST";
export const MEDIC_API = createMedic("MEDIC_API");
//

//MEDIC
//MEDIC
export const MEMBER = "MEMBER";
export const groups = [SELF, CLEAR, MEMBER, FORM];
function createGroup(base) {
  return groups.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const GROUP_REQUEST = "GROUP_REQUEST";
export const GROUP_API = createGroup("GROUP_API");
//

//$(document).ready(function() {
//});
//User
export const PREDEFINED = "PREDEFINED";
export const PASSWORD = "PASSWORD";
export const IMPORT = "IMPORT";
export const users = [
  SELF,
  CLEAR,
  SIGNUP,
  INSTITUTE,
  VERIFY,
  VERIFY_CODE,
  ME,
  EXTERNAL_SIGNUP,
  FORGOT,
  RESET,
  PREDEFINED,
  PASSWORD,
  IMPORT
];
function createUser(base) {
  return users.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const USER_REQUEST = "USER_REQUEST";
export const USER_API = createUser("USER_API");
//
//Research
export const MANU_SCRIPT = "MANU_SCRIPT";
export const MANAGE = "MANAGE";
export const ACTIVITY = "ACTIVITY";
export const MANAGE_ACTIVITY = "MANAGE_ACTIVITY";
export const researchs = [
  SELF,
  CLEAR,
  FORM,
  COMPARE,
  CLONE,
  CLONE_MANU,
  EVALUATION,
  COMMENT,
  FORM_EVALUATION,
  MANU_SCRIPT,
  MANAGE,
  ACTIVITY,
  MANAGE_ACTIVITY
];
function createResearch(base) {
  return researchs.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const RESEARCH_REQUEST = "RESEARCH_REQUEST";
export const RESEARCH_API = createResearch("RESEARCH_API");
//

//Exam
export const TAXONOMY = "TAXONOMY";
export const ORAL = "ORAL";
export const MCQ = "MCQ";
export const MEQ = "MEQ";
export const SEQ = "SEQ";
export const USER = "USER";
export const OPNOTE = "OPNOTE";
export const FORM_OPNOTE = "FORM_OPNOTE";
export const QUESTION = "QUESTION";
export const PROBLEM = "PROBLEM";
export const STUDENT = "STUDENT";
export const FORM_QUESTION = "FORM_QUESTION";
export const VALIDATE = "VALIDATE";
export const exams = [
  SELF,
  CLEAR,
  TAXONOMY,
  ORAL,
  MCQ,
  MEQ,
  SEQ,
  USER,
  OPNOTE,
  FORM_OPNOTE,
  QUESTION,
  PROBLEM,
  STUDENT,
  FORM_QUESTION,
  VALIDATE
];
function createExam(base) {
  return exams.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const EXAM_REQUEST = "EXAM_REQUEST";
export const EXAM_API = createExam("EXAM_API");
//
//Specialty
export const specialties = [SELF, CLEAR, MAJOR];
function createSpecailty(base) {
  return specialties.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const SPECIALTY_REQUEST = "SPECIALTY_REQUEST";
export const SPECIALTY_API = createSpecailty("SPECIALTY_API");
//

//Logbook
export const DISEASE = "DISEASE";
export const PROCEDURE = "PROCEDURE";
export const LOGBOOK_FORM = "LOGBOOK_FORM";
export const LOGBOOK_MANAGE = "LOGBOOK_MANAGE";

export const logbooks = [
  SELF,
  CLEAR,
  PROCEDURE,
  LOGBOOK_FORM,
  FILE,
  LOGBOOK_MANAGE,
  VALIDATE,
  COMMENT,
  DISEASE
];
function createLogbook(base) {
  return logbooks.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const LOGBOOK_REQUEST = "LOGBOOK_REQUEST";
export const LOGBOOK_API = createLogbook("LOGBOOK_API");
//

//Form
export const EXPORT_CSV = "EXPORT_CSV";
export const RESPONSE_RECENT = "RESPONSE_RECENT";
export const forms = [
  SELF,
  CLEAR,
  TEXT,
  ITEM,
  CHECKBOX,
  TYPE,
  MULTIPLE_CHOICE,
  DATE,
  DATETIME,
  TIME,
  SCALE,
  CHECKBOX_GRID,
  IMAGE,
  VIDEO,
  GRID,
  DROPDOWN,
  RESPONSE,
  SECTION_HEADER,
  SECTION,
  LIST,
  EQUATION,
  STAT,
  MOVE,
  TAG,
  CONDITION,
  STAT_GROUP,
  EXPORT_CSV,
  RESPONSE_RECENT
];
function createForms(base) {
  return forms.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const FORM_REQUEST = "FORM_REQUEST";
export const FORM_API = createForms("FORM_API");

//

//Conference
export const DETAIL = "DETAIL";
export const ATTENDANCE = "ATTENDANCE";
export const ATTENDED = "ATTENDED";
export const CONFERENCE = "CONFERENCE";
export const conference = [
  SELF,
  CLEAR,
  DETAIL,
  ATTENDANCE,
  ATTENDED,
  CONFERENCE,
  TYPE
];
function createConference(base) {
  return conference.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const CONFERENCE_REQUEST = "CONFERENCE_REQUEST";
export const CONFERENCE_API = createConference("CONFERENCE_API");

//
function createAPIRequestTypes(base) {
  return [ALL, GETID, GET, POST, PUT, DEL, SEARCH, CLEAR].reduce(
    (acc, type) => {
      acc[type] = createRequestTypes(`${base}_${type}`);
      return acc;
    },
    {}
  );
}

function createRequestTypes(base) {
  return [
    REQUEST,
    SENDING,
    SUCCESS,
    FAILURE,
    CALLBACK_SUCCESS,
    CALLBACK_FAIL,
    CALLBACK_LOADING,
    CALLBACK_OUT,
    CALLBACK_NEW,
    CALLBACK_PRIORITY,
    CALLBACK_CLEAR
  ].reduce((acc, type) => {
    acc[type] = `${base}_${type}`;
    return acc;
  }, {});
}
export const LOGIN = createRequestTypes("LOGIN");
export const LOGOUT = createRequestTypes("LOGOUT");
export const COMPONENT = createRequestTypes("COMPONENT");
export const APP_LOAD = "APP_LOAD";
export const REDIRECT_TO = "REDIRECT_TO";
export const REDIRECT = "REDIRECT";
export const RELOAD = "RELOAD";
export default {
  GET,
  POST,
  PUT,
  DEL,
  GETID,
  ALL,
  CLEAR,
  SEARCH,
  SELF,
  FORM,
  CLONE,
  COMPARE,
  MAJOR,
  RESEARCH_REQUEST,
  USER_REQUEST,
  RESEARCH_API,
  COMPONENT,
  FILE,
  EVALUATION,
  COMMENT,
  SIGNUP,
  TEXT,
  ITEM,
  CHECKBOX,
  MULTIPLE_CHOICE,
  FORM_EVALUATION,
  TYPE,
  DATE,
  DATETIME,
  TIME,
  SCALE,
  CHECKBOX_GRID,
  IMAGE,
  VIDEO,
  INSTITUTE,
  VERIFY,
  GRID,
  DROPDOWN,
  RESPONSE,
  SECTION_HEADER,
  VERIFY_CODE,
  ME,
  WFME_REQUEST,
  WFME_API,
  KPI,
  EXTERNAL_SIGNUP,
  PATIENT,
  SECTION,
  FOLLOWUP,
  MEMBER,
  LATEST_FOLLOWUP,
  COURSE,
  LIST,
  COURSE_OFFER,
  ANSWER,
  FORGOT,
  RESET,
  EQUATION,
  STAT,
  MOVE,
  OUTCOME,
  DEPARTMENT,
  ANNOTATE,
  TAG,
  CONDITION,
  OWN,
  HEADER,
  UPLOAD,
  STAT_GROUP,
  MANU_SCRIPT,
  CLONE_MANU,
  INVENTORY,
  UNIT,
  LOTS,
  MEDICATION,
  OWN_MEDICATION,
  INVOICE,
  EXPORT_CSV,
  MANAGE,
  ACTIVITY,
  MANAGE_ACTIVITY,
  PROCEDURE,
  LOGBOOK_FORM,
  LOGBOOK_MANAGE,
  PREDEFINED,
  VALIDATE,
  PASSWORD,
  IMPORT,
  CURRICULUM,
  FILE_NAME,
  TAXONOMY,
  ORAL,
  MCQ,
  MEQ,
  SEQ,
  USER,
  BUNDLE,
  OPNOTE,
  FORM_OPNOTE,
  QUESTION,
  ACADYEAR,
  OUTCOME_FORM,
  PROBLEM,
  STUDENT,
  FORM_QUESTION,
  CUCAS_USER,
  DETAIL,
  CUCAS,
  DISEASE,
  ATTENDANCE,
  ATTENDED,
  CONFERENCE
};

==> deverhood-react-1.16.59.tgz: package/src/actions/actionType.js <==
export const REQUEST = "REQUEST";
export const SENDING = "SENDING";
export const SUCCESS = "SUCCESS";
export const FAILURE = "FAILURE";
export const CALLBACK_SUCCESS = "CALLBACK_SUCCESS";
export const CALLBACK_FAIL = "CALLBACK_FAIL";
export const CALLBACK_LOADING = "CALLBACK_LOADING";
export const CALLBACK_OUT = "CALLBACK_OUT";
export const CALLBACK_NEW = "CALLBACK_NEW";
export const CALLBACK_PRIORITY = "CALLBACK_PRIORITY";
export const CALLBACK_CLEAR = "CALLBACK_CLEAR";
//ACTIONS
//REST APIs
export const GET = "GET";
export const POST = "POST";
export const PUT = "PUT";
export const DEL = "DEL";
export const GETID = "GETID";
export const ALL = "ALL";
export const SEARCH = "SEARCH";
export const SELF = "SELF";
export const CLEAR = "CLEAR";
export const FORM = "FORM";
export const CLONE = "CLONE";
export const CLONE_MANU = "CLONE_MANU";
export const COMPARE = "COMPARE";
export const MAJOR = "MAJOR";
export const FILE = "FILE";
export const EVALUATION = "EVALUATION";
export const COMMENT = "COMMENT";
export const SIGNUP = "SIGNUP";
export const VERIFY = "VERIFY";
export const INSTITUTE = "INSTITUTE";
export const TEXT = "TEXT";
export const CHECKBOX = "CHECKBOX";
export const MULTIPLE_CHOICE = "MULTIPLE_CHOICE";
export const ITEM = "ITEM";
export const FORM_EVALUATION = "FORM_EVALUATION";
export const TYPE = "TYPE";
export const DATE = "DATE";
export const TIME = "TIME";
export const DATETIME = "DATETIME";
export const SCALE = "SCALE";
export const CHECKBOX_GRID = "CHECKBOX_GRID";
export const IMAGE = "IMAGE";
export const VIDEO = "VIDEO";
export const GRID = "GRID";
export const DROPDOWN = "DROPDOWN";
export const RESPONSE = "RESPONSE";
export const SECTION_HEADER = "SECTION_HEADER";
export const SECTION = "SECTION";
export const VERIFY_CODE = "VERIFY_CODE";
export const ME = "ME";
export const EXTERNAL_SIGNUP = "EXTERNAL_SIGNUP";
export const LIST = "LIST";
export const FORGOT = "FORGOT";
export const RESET = "RESET";
export const EQUATION = "EQUATION";
export const STAT = "STAT";
export const MOVE = "MOVE";
export const TAG = "TAG";
export const CONDITION = "CONDITION";
export const HEADER = "HEADER";
//WFME
export const CURRICULUM = "CURRICULUM";
export const KPI = "KPI";
export const COURSE = "COURSE";
export const COURSE_OFFER = "COURSE_OFFER";
export const ANSWER = "ANSWER";
export const OUTCOME = "OUTCOME";
export const DEPARTMENT = "DEPARTMENT";
export const FILE_NAME = "FILE_NAME";
export const BUNDLE = "BUNDLE";
export const ACADYEAR = "ACADYEAR";
export const OUTCOME_FORM = "OUTCOME_FORM";
export const CUCAS = "CUCAS";
export const CUCAS_INSTRUCTOR = "CUCAS_INSTRUCTOR";
export const CUCAS_USER = "CUCAS_USER";
//WFME
export const wfmes = [
  SELF,
  CLEAR,
  KPI,
  COURSE,
  COURSE_OFFER,
  ANSWER,
  FILE,
  OUTCOME,
  DEPARTMENT,
  CURRICULUM,
  FILE_NAME,
  RESPONSE,
  BUNDLE,
  ACADYEAR,
  OUTCOME_FORM,
  CUCAS,
  CUCAS_INSTRUCTOR,
  CUCAS_USER
];
function createWFME(base) {
  return wfmes.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const WFME_REQUEST = "WFME_REQUEST";
export const WFME_API = createWFME("WFME_API");
//
//HIS
export const INVENTORY = "INVENTORY";
export const UNIT = "UNIT";
export const LOTS = "LOTS";
export const MEDICATION = "MEDICATION";
export const INVOICE = "INVOICE";
export const OWN_MEDICATION = "OWN_MEDICATION";
export const his = [
  SELF,
  CLEAR,
  INVENTORY,
  UNIT,
  LOTS,
  MEDICATION,
  INVOICE,
  OWN_MEDICATION
];
function createHis(base) {
  return his.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const HIS_REQUEST = "HIS_REQUEST";
export const HIS_API = createHis("HIS_API");
//MEDIC
export const PATIENT = "PATIENT";
export const FOLLOWUP = "FOLLOWUP";
export const LATEST_FOLLOWUP = "LATEST_FOLLOWUP";
export const ANNOTATE = "ANNOTATE";
export const OWN = "OWN";
export const UPLOAD = "UPLOAD";
export const STAT_GROUP = "STAT_GROUP"; //Form stat group
//MEDIC
export const medics = [
  SELF,
  CLEAR,
  PATIENT,
  FOLLOWUP,
  LATEST_FOLLOWUP,
  FILE,
  FORM,
  ANNOTATE,
  OWN,
  STAT,
  HEADER,
  UPLOAD,
  STAT_GROUP
];
function createMedic(base) {
  return medics.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const MEDIC_RT_REQUEST = "MEDIC_RT_REQUEST";
export const MEDIC_REQUEST = "MEDIC_REQUEST";
export const MEDIC_API = createMedic("MEDIC_API");
//

//MEDIC
//MEDIC
export const MEMBER = "MEMBER";
export const groups = [SELF, CLEAR, MEMBER, FORM];
function createGroup(base) {
  return groups.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const GROUP_REQUEST = "GROUP_REQUEST";
export const GROUP_API = createGroup("GROUP_API");
//

//$(document).ready(function() {
//});
//User
export const PREDEFINED = "PREDEFINED";
export const PASSWORD = "PASSWORD";
export const IMPORT = "IMPORT";
export const users = [
  SELF,
  CLEAR,
  SIGNUP,
  INSTITUTE,
  VERIFY,
  VERIFY_CODE,
  ME,
  EXTERNAL_SIGNUP,
  FORGOT,
  RESET,
  PREDEFINED,
  PASSWORD,
  IMPORT,
  STUDENT,
  STAT
];
function createUser(base) {
  return users.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const USER_REQUEST = "USER_REQUEST";
export const USER_API = createUser("USER_API");
//
//Research
export const MANU_SCRIPT = "MANU_SCRIPT";
export const MANAGE = "MANAGE";
export const ACTIVITY = "ACTIVITY";
export const MANAGE_ACTIVITY = "MANAGE_ACTIVITY";
export const researchs = [
  SELF,
  CLEAR,
  FORM,
  COMPARE,
  CLONE,
  CLONE_MANU,
  EVALUATION,
  COMMENT,
  FORM_EVALUATION,
  MANU_SCRIPT,
  MANAGE,
  ACTIVITY,
  MANAGE_ACTIVITY
];
function createResearch(base) {
  return researchs.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const RESEARCH_REQUEST = "RESEARCH_REQUEST";
export const RESEARCH_API = createResearch("RESEARCH_API");
//

//Exam
export const TAXONOMY = "TAXONOMY";
export const ORAL = "ORAL";
export const MCQ = "MCQ";
export const MEQ = "MEQ";
export const SEQ = "SEQ";
export const USER = "USER";
export const OPNOTE = "OPNOTE";
export const FORM_OPNOTE = "FORM_OPNOTE";
export const QUESTION = "QUESTION";
export const PROBLEM = "PROBLEM";
export const STUDENT = "STUDENT";
export const FORM_QUESTION = "FORM_QUESTION";
export const VALIDATE = "VALIDATE";
export const exams = [
  SELF,
  CLEAR,
  TAXONOMY,
  ORAL,
  MCQ,
  MEQ,
  SEQ,
  USER,
  OPNOTE,
  FORM_OPNOTE,
  QUESTION,
  PROBLEM,
  STUDENT,
  FORM_QUESTION,
  VALIDATE
];
function createExam(base) {
  return exams.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const EXAM_REQUEST = "EXAM_REQUEST";
export const EXAM_API = createExam("EXAM_API");
//
//Specialty
export const specialties = [SELF, CLEAR, MAJOR];
function createSpecailty(base) {
  return specialties.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const SPECIALTY_REQUEST = "SPECIALTY_REQUEST";
export const SPECIALTY_API = createSpecailty("SPECIALTY_API");
//

//Logbook
export const DISEASE = "DISEASE";
export const PROCEDURE = "PROCEDURE";
export const LOGBOOK_FORM = "LOGBOOK_FORM";
export const LOGBOOK_MANAGE = "LOGBOOK_MANAGE";
export const DISEASE_UPLOAD = "DISEASE_UPLOAD";
export const PROCEDURE_UPLOAD = "PROCEDURE_UPLOAD";

export const logbooks = [
  SELF,
  CLEAR,
  PROCEDURE,
  LOGBOOK_FORM,
  FILE,
  LOGBOOK_MANAGE,
  VALIDATE,
  COMMENT,
  DISEASE,
  INSTITUTE,
  DISEASE_UPLOAD,
  PROCEDURE_UPLOAD
];
function createLogbook(base) {
  return logbooks.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const LOGBOOK_REQUEST = "LOGBOOK_REQUEST";
export const LOGBOOK_API = createLogbook("LOGBOOK_API");
//

//Form
export const EXPORT_CSV = "EXPORT_CSV";
export const RESPONSE_RECENT = "RESPONSE_RECENT";
export const RESPONSED_STUDENT = "RESPONSED_STUDENT";
export const SPECIALTY_FORM = "SPECIALTY_FORM";
export const EMAIL = "EMAIL";
export const forms = [
  SELF,
  CLEAR,
  TEXT,
  ITEM,
  CHECKBOX,
  TYPE,
  MULTIPLE_CHOICE,
  DATE,
  DATETIME,
  TIME,
  SCALE,
  CHECKBOX_GRID,
  IMAGE,
  VIDEO,
  GRID,
  DROPDOWN,
  RESPONSE,
  SECTION_HEADER,
  SECTION,
  LIST,
  EQUATION,
  STAT,
  MOVE,
  TAG,
  CONDITION,
  STAT_GROUP,
  EXPORT_CSV,
  RESPONSE_RECENT,
  STUDENT,
  RESPONSED_STUDENT,
  SPECIALTY_FORM,
  EMAIL
];
function createForms(base) {
  return forms.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const FORM_REQUEST = "FORM_REQUEST";
export const FORM_API = createForms("FORM_API");
//
//Contact
export const contact = [SELF, CLEAR];
function createContact(base) {
  return contact.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const CONTACT_REQUEST = "CONTACT_REQUEST";
export const CONTACT_API = createContact("CONTACT_API");
//
//Conference
export const DETAIL = "DETAIL";
export const ATTENDANCE = "ATTENDANCE";
export const ATTENDED = "ATTENDED";
export const CONFERENCE = "CONFERENCE";
export const UPCOMING = "UPCOMING";
export const conference = [
  SELF,
  CLEAR,
  DETAIL,
  ATTENDANCE,
  ATTENDED,
  CONFERENCE,
  TYPE,
  UPCOMING
];
function createConference(base) {
  return conference.reduce((acc, type) => {
    acc[type] = createAPIRequestTypes(`${base}_${type}`);
    return acc;
  }, {});
}
export const CONFERENCE_REQUEST = "CONFERENCE_REQUEST";
export const CONFERENCE_API = createConference("CONFERENCE_API");

//
function createAPIRequestTypes(base) {
  return [ALL, GETID, GET, POST, PUT, DEL, SEARCH, CLEAR, CALLBACK_OUT].reduce(
    (acc, type) => {
      acc[type] = createRequestTypes(`${base}_${type}`);
      return acc;
    },
    {}
  );
}

function createRequestTypes(base) {
  return [
    REQUEST,
    SENDING,
    SUCCESS,
    FAILURE,
    CALLBACK_SUCCESS,
    CALLBACK_FAIL,
    CALLBACK_LOADING,
    CALLBACK_OUT,
    CALLBACK_NEW,
    CALLBACK_PRIORITY,
    CALLBACK_CLEAR
  ].reduce((acc, type) => {
    acc[type] = `${base}_${type}`;
    return acc;
  }, {});
}
export const LOGIN = createRequestTypes("LOGIN");
export const LOGOUT = createRequestTypes("LOGOUT");
export const COMPONENT = createRequestTypes("COMPONENT");
export const APP_LOAD = "APP_LOAD";
export const REDIRECT_TO = "REDIRECT_TO";
export const REDIRECT = "REDIRECT";
export const RELOAD = "RELOAD";
export default {
  GET,
  POST,
  PUT,
  DEL,
  GETID,
  ALL,
  CLEAR,
  SEARCH,
  SELF,
  FORM,
  CLONE,
  COMPARE,
  MAJOR,
  RESEARCH_REQUEST,
  USER_REQUEST,
  RESEARCH_API,
  COMPONENT,
  FILE,
  EVALUATION,
  COMMENT,
  SIGNUP,
  TEXT,
  ITEM,
  CHECKBOX,
  MULTIPLE_CHOICE,
  FORM_EVALUATION,
  TYPE,
  DATE,
  DATETIME,
  TIME,
  SCALE,
  CHECKBOX_GRID,
  IMAGE,
  VIDEO,
  INSTITUTE,
  VERIFY,
  GRID,
  DROPDOWN,
  RESPONSE,
  SECTION_HEADER,
  VERIFY_CODE,
  ME,
  WFME_REQUEST,
  WFME_API,
  KPI,
  EXTERNAL_SIGNUP,
  PATIENT,
  SECTION,
  FOLLOWUP,
  MEMBER,
  LATEST_FOLLOWUP,
  COURSE,
  LIST,
  COURSE_OFFER,
  ANSWER,
  FORGOT,
  RESET,
  EQUATION,
  STAT,
  MOVE,
  OUTCOME,
  DEPARTMENT,
  ANNOTATE,
  TAG,
  CONDITION,
  OWN,
  HEADER,
  UPLOAD,
  STAT_GROUP,
  MANU_SCRIPT,
  CLONE_MANU,
  INVENTORY,
  UNIT,
  LOTS,
  MEDICATION,
  OWN_MEDICATION,
  INVOICE,
  EXPORT_CSV,
  MANAGE,
  ACTIVITY,
  MANAGE_ACTIVITY,
  PROCEDURE,
  LOGBOOK_FORM,
  LOGBOOK_MANAGE,
  PREDEFINED,
  VALIDATE,
  PASSWORD,
  IMPORT,
  CURRICULUM,
  FILE_NAME,
  TAXONOMY,
  ORAL,
  MCQ,
  MEQ,
  SEQ,
  USER,
  BUNDLE,
  OPNOTE,
  FORM_OPNOTE,
  QUESTION,
  ACADYEAR,
  OUTCOME_FORM,
  PROBLEM,
  STUDENT,
  FORM_QUESTION,
  CUCAS_USER,
  DETAIL,
  CUCAS,
  CUCAS_INSTRUCTOR,
  DISEASE,
  ATTENDANCE,
  ATTENDED,
  CONFERENCE,
  CONTACT_REQUEST,
  CONTACT_API,
  RESPONSED_STUDENT,
  SPECIALTY_FORM,
  DISEASE_UPLOAD,
  PROCEDURE_UPLOAD,
  UPCOMING,
  EMAIL
};
